<?php

declare(strict_types=1);

namespace apexl\Io\modules\formbuilder\Collections;

use apexl\Io\modules\formbuilder\Components\FormKitField\Fieldset;
use Arrayy\Collection\AbstractCollection;

final class FieldsetCollection extends AbstractCollection
{

    public function getType(): string
    {
        return Fieldset::class;
    }
}