<?php

namespace apexl\Io\modules\formbuilder\Components\FormKitField;

use apexl\Io\modules\formbuilder\Traits\HasOptionsProperty;

readonly class RadioGroupFormKitField extends FormKitField
{
    use  HasOptionsProperty;

    protected final const string TYPE = 'radio';

    public function init($options = []): void
    {
        $this->setOptions($options);
    }
}
