<?php

declare(strict_types=1);

namespace apexl\Io\modules\formbuilder\Traits;

trait HasTitleProperty
{
    public final const string PROP__TITLE = 'title';

    public function setTitle(string $title): static
    {
        return $this->setProperty(self::PROP__TITLE, $title);
    }

    abstract public function setProperty(string $name, mixed $value): static;
}

