<?php

namespace apexl\Io\modules\formbuilder\Components\FormKitField;

use apexl\Io\modules\formbuilder\Traits\HasOptionsProperty;
use apexl\Io\modules\formbuilder\Traits\HasPlaceholderProperty;

readonly class SelectFormKitField extends FormKitField
{
    protected final const string TYPE = 'select';

    use HasOptionsProperty;
    use HasPlaceholderProperty;

    public function init($options = []): void
    {
        $this->setOptions($options);
    }
}
