<?php

namespace apexl\Io\modules\formbuilder\Components\FormKitField;

use apexl\Io\modules\formbuilder\Traits\HasPlaceholderProperty;
use apexl\Io\modules\validation\ValidationRules\Email;

readonly class EmailFormKitField extends FormKitField
{
    protected final const string TYPE = 'email';

    use HasPlaceholderProperty;

    public function init(): void
    {
        $this->addValidation(Email::class);
    }
}
