<?php

declare(strict_types=1);

namespace apexl\Io\modules\formbuilder\Interfaces;

interface FormComponent
{
    public function setFormId(string $formId): static;

    public function toSchema(): array;
}